@@ -103,7 +103,7 @@ class make:
                 await ws.send(dumps(self.hs_data))
                 while True:
                     recv = loads(await ws.recv())
-                    if recv != {'status':'OK','status_det':'OK'}:
+                    if recv != {"status":"OK","status_det":"OK"}:
                         if recv['type'] == 'messenger':
                             yield loads(self.crypto.decrypt(recv['data_enc']))
                     else:
@@ -150,7 +150,7 @@ class make:
                 for i in [
                     ('INVALID_AUTH', 'Auth Key vared shodeh na moatabar ast !'),
                     ('NOT_REGISTERED', 'Auth Key vared shodeh na moatabar ast !'),
-                    ('INVALID_INPUT', 'Moshkeli dar darkhast pish oomad !'),
+                    ('INVALID_INPUT', 'Vorudi method na moatabar ast !'),
                     ('TOO_REQUESTS', 'Darkhast bish az had !')
                 ]:
                     if result['status_det'] == i[0]:
@@ -195,7 +195,7 @@ class make:
                             for i in [
                                 ('INVALID_AUTH', 'Auth Key vared shodeh na moatabar ast !'),
                                 ('INVALID_INPUT', 'Vorudi method na moatabar ast !'),
-                                ('NOT_REGISTERED', 'Moshkeli dar darkhast pish oomad !'),
+                                ('NOT_REGISTERED', 'Auth Key vared shodeh na moatabar ast !'),
                                 ('TOO_REQUESTS', 'Darkhast bish az had !')
                             ]:
                                 if result['status_det'] == i[0]:
@@ -204,33 +204,7 @@ class make:
                         continue
                     else:
                         raise IndexError(result)
-
-class tools:
-
-    @staticmethod
-    def getThumbnail(image_bytes):
-        if Image != None:
-            image = Image.open(BytesIO(image_bytes))
-            width, height = image.size
-            if height > width:
-                new_height = 40
-                new_width  = round(new_height * width / height)
-            else:
-                new_width = 40
-                new_height = round(new_width * height / width)
-            image = image.resize((new_width, new_height), Image.ANTIALIAS)
-            changed_image = BytesIO()
-            image.save(changed_image, format='PNG')
-            return b64e(changed_image.getvalue())
-        else:
-            raise ImportWarning('Please install <pillow> and try again')
-
-    @staticmethod
-    def getImageSize(image_bytes:bytes):
-        im = Image.open(BytesIO(image_bytes))
-        width, height = im.size
-        return width , height
-
+                        
 class message:
 
     def __init__(self, data):
@@ -305,17 +279,17 @@ class message:
             pass
 
     def is_user_chat(self):
-        return self.chat_type() == 'User'
+        return self.chat_type() == "User"
 
     def is_group_chat(self):
-        return self.chat_type() == 'Group'
+        return self.chat_type() == "Group"
 
     def is_channel_chat(self):
-        return self.chat_type() == 'Channel'
+        return self.chat_type() == "Channel"
 
     def chat_title(self):
         try:
-            return self.data['show_notifications'][0].get('title', 'None')
+            return self.data["show_notifications"][0].get("title", "None")
         except KeyError:
             try:
                 return self.data['abs_object']['title']
@@ -324,13 +298,39 @@ class message:
 
     def author_title(self):
         try:
-            return self.data['show_notifications'][0].get('text', 'None:Text').split(':')[0] if self.is_group_chat() else self.chat_title()
+            return self.data["show_notifications"][0].get("text", "None:Text").split(":")[0] if self.is_group_chat() else self.chat_title()
         except KeyError:
             try:
                 return self.data['last_message'].get('author_title', 'None')
             except:
                 pass
 
+class tools:
+
+    @staticmethod
+    def getThumbnail(image_bytes):
+        if Image != None:
+            image = Image.open(BytesIO(image_bytes))
+            width, height = image.size
+            if height > width:
+                new_height = 40
+                new_width  = round(new_height * width / height)
+            else:
+                new_width = 40
+                new_height = round(new_width * height / width)
+            image = image.resize((new_width, new_height), Image.ANTIALIAS)
+            changed_image = BytesIO()
+            image.save(changed_image, format='PNG')
+            return b64e(changed_image.getvalue())
+        else:
+            raise ImportWarning('Please install <pillow> and try again')
+
+    @staticmethod
+    def getImageSize(image_bytes:bytes):
+        im = Image.open(BytesIO(image_bytes))
+        width, height = im.size
+        return width , height
+
 class bot:
 
     def __init__(self, auth):
@@ -351,7 +351,7 @@ class bot:
 
     def on_message(self):
         for recv in self.ws():
-            if not tools.message(recv).chat_type() in self.filters['chat_filter'] and not tools.message(recv).message_type() in self.filters['message_filter']:
+            if not message(recv).chat_type() in self.filters['chat_filter'] and not message(recv).message_type() in self.filters['message_filter']:
                 yield recv
             else:
                 continue
@@ -369,9 +369,9 @@ class bot:
     def get_chats_update(self):
         while True:
             chats_update = (self.method('getChatsUpdates', {'state': str(floor(datetime.today().timestamp()) - 250)}))['chats'][0]
-            if not tools.message(chats_update).message_id() in self.got_messages_update:
-                if not tools.message(chats_update).chat_type() in self.filters['chat_filter'] and not tools.message(chats_update).message_type() in self.filters['message_filter']:
-                    self.got_messages_update.append(tools.message(chats_update).message_id())
+            if not message(chats_update).message_id() in self.got_messages_update:
+                if not message(chats_update).chat_type() in self.filters['chat_filter'] and not message(chats_update).message_type() in self.filters['message_filter']:
+                    self.got_messages_update.append(message(chats_update).message_id())
                     return chats_update
                 else:
                     continue
@@ -390,7 +390,7 @@ class bot:
         )
 
     def reply(self, data, custom_text):
-        message = tools.message(data)
+        message = message(data)
         return self.send_text(
             message.chat_id(),
             custom_text,
@@ -658,11 +658,11 @@ class bot_async:
         self.filters['chat_filter'] = chat_filter
         self.filters['message_filter'] = message_filter
 
-    def on_message(self, message):
+    def on_message(self, msg):
         async def main():
             async for recv in self.ws():
-                if not tools.message(recv).chat_type() in self.filters['chat_filter'] and not tools.message(recv).message_type() in self.filters['message_filter']:
-                    await message(recv)
+                if not message(recv).chat_type() in self.filters['chat_filter'] and not message(recv).message_type() in self.filters['message_filter']:
+                    await msg(recv)
                 else:
                     continue
         run(main())
@@ -680,9 +680,9 @@ class bot_async:
     async def get_chats_update(self):
         while True:
             chats_update = (await self.method('getChatsUpdates', {'state': str(floor(datetime.today().timestamp()) - 250)}))['chats'][0]
-            if not tools.message(chats_update).message_id() in self.got_messages_update:
-                if not tools.message(chats_update).chat_type() in self.filters['chat_filter'] and not tools.message(chats_update).message_type() in self.filters['message_filter']:
-                    self.got_messages_update.append(tools.message(chats_update).message_id())
+            if not message(chats_update).message_id() in self.got_messages_update:
+                if not message(chats_update).chat_type() in self.filters['chat_filter'] and not message(chats_update).message_type() in self.filters['message_filter']:
+                    self.got_messages_update.append(message(chats_update).message_id())
                     return chats_update
                 else:
                     continue
@@ -701,7 +701,7 @@ class bot_async:
         )
 
     async def reply(self, data, custom_text):
-        message = tools.message(data)
+        message = message(data)
         return await self.send_text(
             message.chat_id(),
             custom_text,
